# -*- coding: utf-8 -*-
# This software is distributed under the two-clause BSD license.
# Copyright (c) The django-ldapdb project

import sys

if sys.version_info < (3, 8):
    import pkg_resources

    __version__ = pkg_resources.get_distribution('mprov-django-ldapdb').version

else:
    import importlib.metadata

    __version__ = importlib.metadata.version('mprov-django-ldapdb')

VERSION = __version__



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# This software is distributed under the two-clause BSD license.
# Copyright (c) The django-ldapdb project

import os
import sys

import django
from django.core.management import execute_from_command_line

os.environ.setdefault("DJANGO_SETTINGS_MODULE", "examples.settings")

def run_tests():
    execute_from_command_line([os.path.abspath(__file__), 'test'])
    sys.exit(0)

if __name__ == "__main__":
    execute_from_command_line(sys.argv)



# -*- coding: utf-8 -*-
# This software is distributed under the two-clause BSD license.
# Copyright (c) The django-ldapdb project


from django.contrib import admin
from django.urls import include, path

admin.autodiscover()

urlpatterns = [
    path('admin/doc/', include('django.contrib.admindocs.urls')),
    path('admin/', admin.site.urls),
]
